import React, { useEffect, useRef } from 'react';
import * as d3 from 'd3';

const mouthArc = d3.arc()
  .innerRadius(10)
  .outerRadius(10 + 30)
  .startAngle(Math.PI / 2)
  .endAngle(Math.PI * 3 / 2);

const innerRadius = 60;
const outerRadius = 100;


const createPie = d3
    .pie()
    .value(d => d.value)
    .sort(null);

const createArc = d3
  .arc()
  .innerRadius(innerRadius)
  .outerRadius(outerRadius);

const colors = d3.scaleOrdinal(d3.schemeCategory10);
const format = d3.format(".2f");



export const Pie = function ({
  data,
  innerRadius,
  outerRadius,
  width,
  height
 }) {
  const ref = useRef(null);

  console.log(ref);
  
  const pie = createPie(data);
  
  console.log(pie);
  
  const group = d3.select(ref.current);
  const groupWithData = group.selectAll("g.arc").data(pie);


  const groupWithUpdate = groupWithData
    .enter()
    .append("g")
    .attr("class", "arc");

  const path = groupWithUpdate
    .append("path")
    .merge(groupWithData.select("path.arc"));

  path
    .attr("class", "arc")
    .attr("d", createArc)
    .attr("fill", (d, i) => colors(i));

  

  return (
    <svg width={width} height={height}>
      <g
        ref={ref}
        transform={`translate(${outerRadius} ${outerRadius})`}
      >
        <path 
          d={mouthArc()}
        />
      </g>
    </svg>
  );
};
